package com.cn.fdapfe.biz.service.impl;

import java.util.List;
import com.cn.fdapfe.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.cn.fdapfe.biz.mapper.EvaluationIndicatorMapper;
import com.cn.fdapfe.biz.domain.EvaluationIndicator;
import com.cn.fdapfe.biz.service.IEvaluationIndicatorService;

/**
 * 评估指标体系管理Service业务层处理
 * 
 * @author Allen
 * @date 2025-03-07
 */
@Service
public class EvaluationIndicatorServiceImpl implements IEvaluationIndicatorService 
{
    @Autowired
    private EvaluationIndicatorMapper evaluationIndicatorMapper;

    /**
     * 查询评估指标体系管理
     * 
     * @param id 评估指标体系管理主键
     * @return 评估指标体系管理
     */
    @Override
    public EvaluationIndicator selectEvaluationIndicatorById(Long id)
    {
        return evaluationIndicatorMapper.selectEvaluationIndicatorById(id);
    }

    /**
     * 查询评估指标体系管理列表
     * 
     * @param evaluationIndicator 评估指标体系管理
     * @return 评估指标体系管理
     */
    @Override
    public List<EvaluationIndicator> selectEvaluationIndicatorList(EvaluationIndicator evaluationIndicator)
    {
        return evaluationIndicatorMapper.selectEvaluationIndicatorList(evaluationIndicator);
    }

    /**
     * 新增评估指标体系管理
     * 
     * @param evaluationIndicator 评估指标体系管理
     * @return 结果
     */
    @Override
    public int insertEvaluationIndicator(EvaluationIndicator evaluationIndicator)
    {
        evaluationIndicator.setCreateTime(DateUtils.getNowDate());
        return evaluationIndicatorMapper.insertEvaluationIndicator(evaluationIndicator);
    }

    /**
     * 修改评估指标体系管理
     * 
     * @param evaluationIndicator 评估指标体系管理
     * @return 结果
     */
    @Override
    public int updateEvaluationIndicator(EvaluationIndicator evaluationIndicator)
    {
        evaluationIndicator.setUpdateTime(DateUtils.getNowDate());
        return evaluationIndicatorMapper.updateEvaluationIndicator(evaluationIndicator);
    }

    /**
     * 批量删除评估指标体系管理
     * 
     * @param ids 需要删除的评估指标体系管理主键
     * @return 结果
     */
    @Override
    public int deleteEvaluationIndicatorByIds(Long[] ids)
    {
        return evaluationIndicatorMapper.deleteEvaluationIndicatorByIds(ids);
    }

    /**
     * 删除评估指标体系管理信息
     * 
     * @param id 评估指标体系管理主键
     * @return 结果
     */
    @Override
    public int deleteEvaluationIndicatorById(Long id)
    {
        return evaluationIndicatorMapper.deleteEvaluationIndicatorById(id);
    }
}
